﻿using e_commerceProject.Models;
using e_commerceProject.Services.OrderService;
using Microsoft.AspNetCore.Http;
using e_commerceProject.Services.ProductService;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Http.HttpResults;
using Microsoft.AspNetCore.Mvc;
using System.Data;
using System.Security.Claims;
using e_commerceProject.Services.UserService;
using e_commerceProject.Services.OrderStatusService;

namespace e_commerceProject.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class OrderController : ControllerBase
    {
        private readonly IOrderService _orderService;
        private readonly IUserService _userService;
        private readonly IOrderStatusService _orderStatusService;

        public OrderController(IOrderService orderService, IUserService userService, IOrderStatusService orderStatusService)
        {
            _orderService = orderService;
            _userService = userService;
            _orderStatusService = orderStatusService;
        }

        [HttpPost,Authorize]
        public async Task<IActionResult> AddOrder(OrderCreateDTO order)
        {
            try
            {
                var newOrder = await _orderService.AddOrderAsync(order);

                if (newOrder != null)
                {
                    return Ok(new { OrderId = newOrder.Id }); 
                }
                else
                {
                    return BadRequest("Failed to create order.");
                }
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while creating an order: {ex.Message}");
            }
        }

        [HttpPut("updateStatus"), Authorize]
        public async Task<IActionResult> UpdateOrderStatus(int orderId, int newStatusId)
        {
            try
            {
                var result = await _orderStatusService.UpdateOrderStatus(orderId, newStatusId);

                if (result.Contains("Error"))
                    return StatusCode(StatusCodes.Status500InternalServerError, result);
                if (result.Contains("Order not found"))
                    return StatusCode(StatusCodes.Status404NotFound, result);

                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while updating an order: {ex.Message}");
            }
        }

        [HttpGet("getStatusByOrderId"), Authorize]
        public async Task<IActionResult> GetOrderStatus(int orderId)
        {
            try
            {
                var result = await _orderService.GetOrderStatus(orderId);

                if (result.Contains("Error"))
                    return StatusCode(StatusCodes.Status500InternalServerError, result);
                if (result.Contains("Order not found"))
                    return StatusCode(StatusCodes.Status404NotFound, result);

                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while getting status order: {ex.Message}");
            }

        }
    }
}
