﻿using e_commerceProject.Models;
using e_commerceProject.Services.ProductService;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace e_commerceProject.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class ProductController : ControllerBase
    {
        private readonly IProductService _productService;

        public ProductController(IProductService productService)
        {
            _productService = productService;
        }

        [HttpGet, Authorize(Roles = "Admin")]
        public async Task<ActionResult<List<ProductModel>>> GetAllProducts()
        {
            try
            {
                return await _productService.GetAllProducts();
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while getting all products: {ex.Message}");
            }

        }

        [HttpGet("{id}"),Authorize(Roles = "Admin")]
        public async Task<ActionResult<ProductModel>> GetSingleProduct(int id)
        {
            try
            {
                var result = await _productService.GetSingleProduct(id);
                if (result is null)
                    return StatusCode(StatusCodes.Status404NotFound, "Product not found.");

                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while getting single product: {ex.Message}");
            }
        }

        [HttpPost,Authorize(Roles = "Admin")]
        public async Task<ActionResult<List<ProductModel>>> AddProduct(ProductDTO productDto)
        {
            try
            {
                var product = new ProductModel
                {
                    Name = productDto.Name,
                    Description = productDto.Description,
                    Price = productDto.Price,
                    Stock = productDto.Stock
                };
                var result = await _productService.AddProduct(product);
                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while adding a product: {ex.Message}");
            }
        }

        [HttpPut("{id}"),Authorize(Roles = "Admin")]
        public async Task<ActionResult<List<ProductModel>>> UpdateProduct(int id, ProductDTO productDto)
        {
            try
            {
                var product = new ProductModel
                {
                    Name = productDto.Name,
                    Description = productDto.Description,
                    Price = productDto.Price,
                    Stock = productDto.Stock
                };
                var result = await _productService.UpdateProduct(id, product);
                if (result is null)
                    return StatusCode(StatusCodes.Status404NotFound, "Product not found.");

                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while updating a product: {ex.Message}");
            }
        }

        [HttpDelete("{id}"),Authorize(Roles = "Admin")]
        public async Task<ActionResult<List<ProductModel>>> DeleteProduct(int id)
        {
            try
            {
                var result = await _productService.DeleteProduct(id);
                if (result is null)
                    return StatusCode(StatusCodes.Status404NotFound, "Product not found.");

                return StatusCode(StatusCodes.Status200OK, result);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, $"Error while deleting a product: {ex.Message}");
            }
        }
    }
}
