﻿using e_commerceProject.Models;
using e_commerceProject.Services.PasswordHasher;
using Microsoft.EntityFrameworkCore;
using System.Data;

namespace e_commerceProject.Services.OrderStatusService
{
    public class OrderStatusService : IOrderStatusService
    {
        private readonly ApplicationDbContext _context;

        public OrderStatusService(ApplicationDbContext context)
        {
            _context = context;
        }

        public async Task<OrderStatus?> GetSingleStatus(int id)
        {
           return await _context.OrderStatus.FindAsync(id);
        }

        public async Task<string> UpdateOrderStatus(int orderId, int newStatusId)
        {
            try
            {
                var order = await _context.Orders.Include(o => o.OrderStatus).FirstOrDefaultAsync(o => o.Id == orderId);

                if (order == null)
                {
                    return "Order not found";
                }

                var status = await _context.OrderStatus.FirstOrDefaultAsync(s => s.Id == newStatusId);
                if(status != null)
                {
                    order.OrderStatus = status;
                }

                await _context.SaveChangesAsync();

                return $"Status of an order {orderId} is updated to: {newStatusId}";
            }
            catch (Exception ex)
            {
                return $"An error occured while trying to update a status of an order: {ex.Message}";
            }
        }

    }
}
