﻿using e_commerceProject.Models;
using Microsoft.EntityFrameworkCore;
using Microsoft.Win32;

namespace e_commerceProject.Services.ProductService
{
    public class ProductService : IProductService
    {
        private readonly ApplicationDbContext _context;

        public ProductService(ApplicationDbContext context)
        {
            _context = context;
        }

        public async Task<List<ProductModel>> GetAllProducts()
        {
            return await _context.Product.ToListAsync();
        }
        public async Task<List<ProductModel>> GetAllProductsWithIds(List<int> ids)
        {
            return await _context.Product
                .Where(product => product != null && product.Id != null && ids.Contains((int)product.Id))
                .ToListAsync();
        }

        public async Task<ProductModel?> GetSingleProduct(int id)
        {
            var product = await _context.Product.FindAsync(id);

            return product;
        }

        public async Task<List<ProductModel>> AddProduct(ProductModel product)
        {
            _context.Product.Add(product);
            await _context.SaveChangesAsync();
            return await _context.Product.ToListAsync();
        }

        public async Task<List<ProductModel>?> UpdateProduct(int id, ProductModel request)
        {
            var product = await _context.Product.FindAsync(id);

            product.Name = request.Name;
            product.Description = request.Description;
            product.Price = request.Price;
            product.Stock = request.Stock;

            await _context.SaveChangesAsync();

            return await _context.Product.ToListAsync();
        }

        public async Task<List<ProductModel>?> DeleteProduct(int id)
        {
            var product = await _context.Product.FindAsync(id);

            _context.Product.Remove(product);
            await _context.SaveChangesAsync();

            return await _context.Product.ToListAsync();
        }

        public async Task<List<ProductModel>?> UpdateProducts(List<ProductModel> updatedProducts)
        {
            if (updatedProducts.Count == 0)
            {
                throw new Exception($"You must send at least one product.");
            }
            foreach (var product in updatedProducts)
            {
                var existingProduct = await _context.Product.FindAsync(product.Id);
                if (existingProduct != null)
                {
                    existingProduct.Stock = product.Stock;
                    await _context.SaveChangesAsync();
                }
            }
            return updatedProducts;
        }
    }
}
