﻿using e_commerceProject.Models;
using e_commerceProject.Services.PasswordHasher;
using Microsoft.EntityFrameworkCore;
using System.Data;
using System.Security.Claims;

namespace e_commerceProject.Services.UserService
{
    public class UserService : IUserService 
    {
        private readonly ApplicationDbContext _context;
        private readonly IPasswordHasher _passwordHasher;
        public static UserModel user = new UserModel();
        private readonly IHttpContextAccessor _httpContextAccessor;

        public UserService(IHttpContextAccessor httpContextAccessor, ApplicationDbContext context, IPasswordHasher passwordHasher)
        {
            _httpContextAccessor = httpContextAccessor;
            _context = context;
            _passwordHasher = passwordHasher;   
        }

        public async Task<List<UserModel>> GetAllUsers()
        {
            return await _context.Users.ToListAsync();
        }

        public async Task<UserModel?> GetSingleUser(int id)
        {
            return await _context.Users.FindAsync(id);
        }

        public async Task<UserModel> CreateUser(UserRegisterDTO userDTO)
        {
            var passwordHash = _passwordHasher.Hash(userDTO.Password);
            var user = new UserModel
            {
                Username = userDTO.Username,
                Password = passwordHash,
                Email = userDTO.Email,
                Role = userDTO.Role

            }; 
            _context.Users.Add(user);
            await _context.SaveChangesAsync();
            return user;
        }

        public async Task<UserModel?> GetSingleUserByUsername(string username)
        {

            return await _context.Users.FirstOrDefaultAsync(mytable => mytable.Username == username);
        }

        public async Task<string> GetMyNameAsync()
        {
            var result = string.Empty;
            var user = _httpContextAccessor.HttpContext?.User;

            if (user != null && user.Identity != null && user.Identity.IsAuthenticated)
            {
                var usernameClaim = user.FindFirst(ClaimTypes.Name);
                if (usernameClaim != null)
                {
                    result = usernameClaim.Value;
                }
            }

            return await Task.FromResult(result);
        }
    }
}
